.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2017-12-31)
++++++++++++++++++

* Added syncing of database with online HPO resources.

0.3.0 (2017-01-02)
++++++++++++++++++

* Added Disease genes model and REST API.
* Synced Disease genes from online HPO resource.

0.3.1 (2017-01-04)
++++++++++++++++++

* Fixed minor bugs
* Added better test coverage for hpo_sync.

0.4.0 (2017-01-05)
++++++++++++++++++

* Improved REST API filters.

0.4.1 (2017-01-09)
++++++++++++++++++

* Fixed issues with migrations.

0.4.2 (2017-01-12)
++++++++++++++++++

* Fixed route names for SimpleRouter.
